lium.sdk.Lium
=============

.. currentmodule:: lium.sdk

.. autoclass:: Lium

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Lium.__init__
      ~Lium.add_wallet
      ~Lium.backup_config
      ~Lium.backup_create
      ~Lium.backup_delete
      ~Lium.backup_list
      ~Lium.backup_logs
      ~Lium.backup_now
      ~Lium.balance
      ~Lium.cancel_scheduled_termination
      ~Lium.create_template
      ~Lium.default_docker_template
      ~Lium.down
      ~Lium.download
      ~Lium.edit
      ~Lium.exec
      ~Lium.exec_all
      ~Lium.get_default_images
      ~Lium.get_executor
      ~Lium.get_my_user_id
      ~Lium.get_template
      ~Lium.get_template_by_image_name
      ~Lium.gpu_types
      ~Lium.install_jupyter
      ~Lium.ls
      ~Lium.pod
      ~Lium.ps
      ~Lium.reboot
      ~Lium.restore
      ~Lium.rm
      ~Lium.rsync
      ~Lium.schedule_termination
      ~Lium.scp
      ~Lium.ssh
      ~Lium.ssh_connection
      ~Lium.stream_exec
      ~Lium.switch_template
      ~Lium.templates
      ~Lium.up
      ~Lium.update_template
      ~Lium.upload
      ~Lium.volume
      ~Lium.volume_create
      ~Lium.volume_delete
      ~Lium.volume_update
      ~Lium.volumes
      ~Lium.wait_ready
      ~Lium.wait_template_ready
      ~Lium.wallets
   
   

   
   
   